function [ret,x0,str,ts,xts]=simclas1(t,x,u,flag);
%SIMCLAS1	is the M-file description of the SIMULINK system named SIMCLAS1.
%	The block-diagram can be displayed by typing: SIMCLAS1.
%
%	SYS=SIMCLAS1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIMCLAS1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIMCLAS1 with a FLAG of zero:
%	[SIZES]=SIMCLAS1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[47,50,1201,679])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'tsim')
set_param(sys,'Min step size', 'tsim/1000')
set_param(sys,'Max step size', 'tsim/1000')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['SIMULATION SYSTEME AVEC ROUE PARFAITE',13,'SANS COUPLES PERTURBATEURS']])
set_param([sys,'/',['SIMULATION SYSTEME AVEC ROUE PARFAITE',13,'SANS COUPLES PERTURBATEURS']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[410,5,415,10])

add_block('built-in/Note',[sys,'/',['Initialisation par scaodat3 dans l''espace Matlab']])
set_param([sys,'/',['Initialisation par scaodat3 dans l''espace Matlab']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[545,595,550,600])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','-6e-4*2',...
		'position',[345,344,415,386])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','-8.6e-5*4',...
		'position',[350,271,425,309])

add_block('built-in/Note',[sys,'/',['ROUE',13,'SIMPLE']])
set_param([sys,'/',['ROUE',13,'SIMPLE']],...
		'ForeGround',7,...
		'BackGround',7,...
		'Font Weight','bold',...
		'position',[400,195,405,200])

add_block('built-in/Note',[sys,'/',['Rappel',13,'proportionnel']])
set_param([sys,'/',['Rappel',13,'proportionnel']],...
		'ForeGround',7,...
		'BackGround',7,...
		'Font Weight','bold',...
		'position',[385,235,390,240])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[445,250,470,405])

add_block('built-in/Note',[sys,'/','Amortissement'])
set_param([sys,'/','Amortissement'],...
		'position',[370,315,375,320])

add_block('built-in/Note',[sys,'/',['Matrice d''inertie diagonale ( sans produits d''inertie )']])
set_param([sys,'/',['Matrice d''inertie diagonale ( sans produits d''inertie )']],...
		'position',[430,545,435,550])

add_block('built-in/Note',[sys,'/',['Mode petits angles, jusqu'' 20']])
set_param([sys,'/',['Mode petits angles, jusqu'' 20']],...
		'position',[370,525,375,530])

add_block('built-in/Note',[sys,'/','Roue parfaite = Rponses  instantanes des capteurs  de position, de vitesse, et de la roue'])
set_param([sys,'/','Roue parfaite = Rponses  instantanes des capteurs  de position, de vitesse, et de la roue'],...
		'position',[545,460,550,465])

add_block('built-in/Note',[sys,'/','Couples perturbateurs ngligs'])
set_param([sys,'/','Couples perturbateurs ngligs'],...
		'position',[460,500,465,505])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'Vgain','0.000100',...
		'Hgain','600.000000',...
		'Vmax','0.000200',...
		'Hmax','1200.000000',...
		'Window',[652,557,1081,1024])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[585,144,650,206])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','C_roue',...
		'buffer','points_trace',...
		'position',[580,210,660,240])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','-+',...
		'position',[220,238,250,342])

add_block('built-in/Constant',[sys,'/',['Angle  de ',13,'rfrence']])
set_param([sys,'/',['Angle  de ',13,'rfrence']],...
		'hide name',0,...
		'Value','0.01',...
		'Mask Display','CONSIGNE',...
		'position',[115,246,190,284])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[280,183,330,207])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'hide name',0,...
		'Gain','1/It',...
		'position',[585,310,620,350])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[155,373,510,623])
open_system([sys,'/','Subsystem'])

add_block('built-in/Sum',[sys,'/','Subsystem/Sum1'])
set_param([sys,'/','Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','++++',...
		'position',[245,54,265,191])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant1'])
set_param([sys,'/','Subsystem/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple aerod',...
		'position',[65,129,165,151])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant2'])
set_param([sys,'/','Subsystem/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple magneto\nactuateurs',...
		'position',[65,91,165,119])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant3'])
set_param([sys,'/','Subsystem/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple magneto\ninterne',...
		'position',[65,54,165,86])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant4'])
set_param([sys,'/','Subsystem/Constant4'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple gradient\nde gravit',...
		'position',[65,161,165,189])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain5'])
set_param([sys,'/','Subsystem/Gain5'],...
		'hide name',0,...
		'Gain','0',...
		'position',[190,162,215,188])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain2'])
set_param([sys,'/','Subsystem/Gain2'],...
		'hide name',0,...
		'Gain','0',...
		'position',[190,127,215,153])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain3'])
set_param([sys,'/','Subsystem/Gain3'],...
		'hide name',0,...
		'Gain','0',...
		'position',[190,92,215,118])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain4'])
set_param([sys,'/','Subsystem/Gain4'],...
		'hide name',0,...
		'Gain','0',...
		'position',[190,57,215,83])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[295,115,315,135])
add_line([sys,'/','Subsystem'],[220,105;240,105])
add_line([sys,'/','Subsystem'],[220,175;240,175])
add_line([sys,'/','Subsystem'],[220,140;240,140])
add_line([sys,'/','Subsystem'],[220,70;240,70])
add_line([sys,'/','Subsystem'],[170,175;185,175])
add_line([sys,'/','Subsystem'],[170,70;185,70])
add_line([sys,'/','Subsystem'],[170,105;185,105])
add_line([sys,'/','Subsystem'],[170,140;185,140])
add_line([sys,'/','Subsystem'],[270,125;290,125])
set_param([sys,'/','Subsystem'],...
		'Mask Display','COUPLES\nPERTURBATEURS')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[575,249,690,301])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'position',[715,248,740,357])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','teta_prim0',...
		'position',[765,283,810,327])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'Vgain','0.500000',...
		'Hgain','600.000000',...
		'Vmax','1.000000',...
		'Hmax','1200.000000',...
		'Window',[224,557,650,1024])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[990,219,1055,281])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'position',[185,185,205,205])

add_block('built-in/Note',[sys,'/','ROUE'])
set_param([sys,'/','ROUE'],...
		'hide name',0,...
		'position',[390,315,395,320])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','tetaprime',...
		'buffer','points_trace',...
		'position',[975,175,1055,205])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'hide name',0,...
		'Initial','teta_zero*4',...
		'position',[860,283,910,327])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','teta',...
		'buffer','points_trace',...
		'position',[985,290,1065,320])

add_block('built-in/Note',[sys,'/','Simulink simclas1.m'])
set_param([sys,'/','Simulink simclas1.m'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Underline',1,...
		'Font Size',18,...
		'position',[510,75,515,80])

add_block('built-in/Note',[sys,'/',['Gradient de gravit nglig',13,'']])
set_param([sys,'/',['Gradient de gravit nglig',13,'']],...
		'position',[450,480,455,485])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Initialisation par\n\nscaodat3.m',...
		'Mask Dialogue','eval(''scaodat3'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[960,355,1125,416])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir la courbe\n\nteta (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,teta);grid;'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[960,430,1135,491])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\ntetaprime (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,tetaprime);grid;'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[960,500,1135,561])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir la courbe\n\nCouple roue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,C_roue);grid;'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[960,570,1135,631])
add_line(sys,[815,305;855,305])
add_line(sys,[915,305;980,305])
add_line(sys,[745,305;760,305])
add_line(sys,[430,290;440,290])
add_line(sys,[420,365;440,365])
add_line(sys,[825,305;825,410;330,410;340,365])
add_line(sys,[825,305;825,190;970,190])
add_line(sys,[695,275;710,275])
add_line(sys,[195,265;215,265])
add_line(sys,[255,290;345,290])
add_line(sys,[935,305;935,450;160,445;160,315;215,315])
add_line(sys,[936,305;935,250;985,250])
add_line(sys,[625,330;710,330])
add_line(sys,[475,330;580,330])
add_line(sys,[210,195;275,195])
add_line(sys,[516,330;515,225;575,225])
add_line(sys,[515,225;515,175;580,175])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
