function [ret,x0,str,ts,xts]=simclas2(t,x,u,flag);
%SIMCLAS2	is the M-file description of the SIMULINK system named SIMCLAS2.
%	The block-diagram can be displayed by typing: SIMCLAS2.
%
%	SYS=SIMCLAS2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIMCLAS2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIMCLAS2 with a FLAG of zero:
%	[SIZES]=SIMCLAS2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[99,84,1259,738])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'tsim')
set_param(sys,'Min step size', 'tsim/1000')
set_param(sys,'Max step size', 'tsim/1000')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','teta',...
		'buffer','points_trace',...
		'position',[980,225,1060,255])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'hide name',0,...
		'Initial','teta_zero*4',...
		'position',[855,218,905,262])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','tetaprime',...
		'buffer','points_trace',...
		'position',[970,110,1050,140])

add_block('built-in/Note',[sys,'/','ROUE'])
set_param([sys,'/','ROUE'],...
		'hide name',0,...
		'position',[385,250,390,255])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'position',[180,120,200,140])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'Vgain','0.500000',...
		'Hgain','300.000000',...
		'Vmax','1.000000',...
		'Hmax','600.000000',...
		'Window',[178,511,579,891])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[985,154,1050,216])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','teta_prim0',...
		'position',[760,218,805,262])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'position',[710,183,735,292])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[155,9306485,510,9306735])

add_block('built-in/Sum',[sys,'/','Subsystem/Sum1'])
set_param([sys,'/','Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','++++',...
		'position',[245,54,265,191])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant1'])
set_param([sys,'/','Subsystem/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple aerod',...
		'position',[65,129,165,151])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant2'])
set_param([sys,'/','Subsystem/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple magneto\nactuateurs',...
		'position',[65,91,165,119])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant3'])
set_param([sys,'/','Subsystem/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple magneto\ninterne',...
		'position',[65,54,165,86])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant4'])
set_param([sys,'/','Subsystem/Constant4'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple gradient\nde gravit',...
		'position',[65,161,165,189])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain5'])
set_param([sys,'/','Subsystem/Gain5'],...
		'hide name',0,...
		'Gain','0',...
		'position',[190,162,215,188])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain2'])
set_param([sys,'/','Subsystem/Gain2'],...
		'hide name',0,...
		'Gain','0',...
		'position',[190,127,215,153])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain3'])
set_param([sys,'/','Subsystem/Gain3'],...
		'hide name',0,...
		'Gain','0',...
		'position',[190,92,215,118])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain4'])
set_param([sys,'/','Subsystem/Gain4'],...
		'hide name',0,...
		'Gain','0',...
		'position',[190,57,215,83])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[295,115,315,135])
add_line([sys,'/','Subsystem'],[220,105;240,105])
add_line([sys,'/','Subsystem'],[220,175;240,175])
add_line([sys,'/','Subsystem'],[220,140;240,140])
add_line([sys,'/','Subsystem'],[220,70;240,70])
add_line([sys,'/','Subsystem'],[170,175;185,175])
add_line([sys,'/','Subsystem'],[170,70;185,70])
add_line([sys,'/','Subsystem'],[170,105;185,105])
add_line([sys,'/','Subsystem'],[170,140;185,140])
add_line([sys,'/','Subsystem'],[270,125;290,125])
set_param([sys,'/','Subsystem'],...
		'Mask Display','COUPLES\nPERTURBATEURS')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[570,184,685,236])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[275,118,325,142])

add_block('built-in/Constant',[sys,'/',['Angle  de ',13,'rfrence']])
set_param([sys,'/',['Angle  de ',13,'rfrence']],...
		'hide name',0,...
		'Value','0.01',...
		'Mask Display','CONSIGNE',...
		'position',[110,181,185,219])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','-+',...
		'position',[215,173,245,277])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','C_roue',...
		'buffer','points_trace',...
		'position',[575,145,655,175])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'Vgain','0.000200',...
		'Hgain','300.000000',...
		'Vmax','0.000400',...
		'Hmax','600.000000',...
		'Window',[734,505,1163,972])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[580,79,645,141])

add_block('built-in/Note',[sys,'/',['Gradient de gravit nglig',13,'']])
set_param([sys,'/',['Gradient de gravit nglig',13,'']],...
		'position',[440,415,445,420])

add_block('built-in/Note',[sys,'/','Couples perturbateurs ngligs'])
set_param([sys,'/','Couples perturbateurs ngligs'],...
		'position',[455,435,460,440])

add_block('built-in/Note',[sys,'/','Roue parfaite = Rponses  instantanes des capteurs  de position, de vitesse, et de la roue'])
set_param([sys,'/','Roue parfaite = Rponses  instantanes des capteurs  de position, de vitesse, et de la roue'],...
		'position',[540,395,545,400])

add_block('built-in/Note',[sys,'/',['Mode petits angles, jusqu'' 20']])
set_param([sys,'/',['Mode petits angles, jusqu'' 20']],...
		'position',[365,460,370,465])

add_block('built-in/Note',[sys,'/',['Matrice d''inertie diagonale ( sans produits d''inertie )']])
set_param([sys,'/',['Matrice d''inertie diagonale ( sans produits d''inertie )']],...
		'position',[425,480,430,485])

add_block('built-in/Note',[sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'SANS COUPLES PERTURBATEURS']])
set_param([sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'SANS COUPLES PERTURBATEURS']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[410,5,415,10])

add_block('built-in/Note',[sys,'/','Amortissement'])
set_param([sys,'/','Amortissement'],...
		'position',[365,250,370,255])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[440,185,465,340])

add_block('built-in/Note',[sys,'/',['Rappel',13,'proportionnel']])
set_param([sys,'/',['Rappel',13,'proportionnel']],...
		'ForeGround',7,...
		'BackGround',7,...
		'Font Weight','bold',...
		'position',[380,170,385,175])

add_block('built-in/Note',[sys,'/',['ROUE',13,'SIMPLE']])
set_param([sys,'/',['ROUE',13,'SIMPLE']],...
		'ForeGround',7,...
		'BackGround',7,...
		'Font Weight','bold',...
		'position',[395,130,400,135])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','-8.6e-5*4',...
		'position',[345,206,420,244])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','-6e-4*2',...
		'position',[340,279,410,321])

add_block('built-in/Transport Delay',[sys,'/','Retard1'])
set_param([sys,'/','Retard1'],...
		'orientation',2,...
		'Delay Time','0.5',...
		'Initial Input','teta_prim0',...
		'position',[520,344,580,376])

add_block('built-in/Transport Delay',[sys,'/','Retard2'])
set_param([sys,'/','Retard2'],...
		'Delay Time','0.2',...
		'Initial Input','teta_zero',...
		'position',[265,209,325,241])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'hide name',0,...
		'Gain','1/It',...
		'position',[555,245,590,285])

add_block('built-in/Transport Delay',[sys,'/','Retard3'])
set_param([sys,'/','Retard3'],...
		'Delay Time','0.2',...
		'position',[610,249,670,281])

add_block('built-in/Note',[sys,'/','Simulink simclas2.m'])
set_param([sys,'/','Simulink simclas2.m'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Underline',1,...
		'Font Size',18,...
		'position',[860,50,865,55])

add_block('built-in/Note',[sys,'/',['Initialisation par scao3dat dans l''espace Matlab']])
set_param([sys,'/',['Initialisation par scao3dat dans l''espace Matlab']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[430,520,435,525])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Initialisation par\n\nscaodat3.m',...
		'Mask Dialogue','eval(''scaodat3'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[955,285,1120,346])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir la courbe\n\nteta (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,teta);grid;'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[955,360,1130,421])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\ntetaprime (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,tetaprime);grid;'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[955,425,1130,486])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir la courbe\n\nCouple roue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,C_roue);grid;'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[955,490,1130,551])
add_line(sys,[810,240;850,240])
add_line(sys,[910,240;975,240])
add_line(sys,[740,240;755,240])
add_line(sys,[425,225;435,225])
add_line(sys,[415,300;435,300])
add_line(sys,[820,240;820,125;965,125])
add_line(sys,[690,210;705,210])
add_line(sys,[190,200;210,200])
add_line(sys,[930,240;930,400;155,395;155,250;210,250])
add_line(sys,[931,240;930,185;980,185])
add_line(sys,[470,265;550,265])
add_line(sys,[205,130;270,130])
add_line(sys,[511,265;510,160;570,160])
add_line(sys,[510,160;510,110;575,110])
add_line(sys,[820,240;820,360;585,360])
add_line(sys,[515,360;275,360;275,300;335,300])
add_line(sys,[250,225;260,225])
add_line(sys,[330,225;340,225])
add_line(sys,[595,265;605,265])
add_line(sys,[675,265;705,265])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
