function [ret,x0,str,ts,xts]=simclas4(t,x,u,flag);
%SIMCLAS4	is the M-file description of the SIMULINK system named SIMCLAS4.
%	The block-diagram can be displayed by typing: SIMCLAS4.
%
%	SYS=SIMCLAS4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SIMCLAS4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SIMCLAS4 with a FLAG of zero:
%	[SIZES]=SIMCLAS4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,51,1246,711])
     open_system(sys)
end;
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'tsim/20')
set_param(sys,'Min step size', 'tsim/1000')
set_param(sys,'Max step size', 'tsim/1000')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'hide name',0,...
		'Initial','teta_zero',...
		'position',[855,218,905,262])

add_block('built-in/Note',[sys,'/','ROUE'])
set_param([sys,'/','ROUE'],...
		'hide name',0,...
		'position',[385,250,390,255])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'position',[180,120,200,140])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','teta_prim0',...
		'position',[760,218,805,262])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[275,118,325,142])

add_block('built-in/Constant',[sys,'/',['Angle  de ',13,'rfrence']])
set_param([sys,'/',['Angle  de ',13,'rfrence']],...
		'hide name',0,...
		'Value','0.01',...
		'Mask Display','CONSIGNE',...
		'position',[110,181,185,219])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','-+',...
		'position',[215,173,245,277])

add_block('built-in/Note',[sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'AVEC GRADIENT DE GRAVITE ET COUPLE AERODYNAMIQUE']])
set_param([sys,'/',['SIMULATION SYSTEME AVEC ROUE RETARDS PRIS EN COMPTE',13,'AVEC GRADIENT DE GRAVITE ET COUPLE AERODYNAMIQUE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[410,5,415,10])

add_block('built-in/Note',[sys,'/','Amortissement'])
set_param([sys,'/','Amortissement'],...
		'position',[365,250,370,255])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[440,185,465,340])

add_block('built-in/Note',[sys,'/',['Rappel',13,'proportionnel']])
set_param([sys,'/',['Rappel',13,'proportionnel']],...
		'ForeGround',7,...
		'BackGround',7,...
		'Font Weight','bold',...
		'position',[380,170,385,175])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','-8.6e-5',...
		'position',[345,206,420,244])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','-6e-4*2',...
		'position',[340,279,410,321])

add_block('built-in/Transport Delay',[sys,'/','Retard2'])
set_param([sys,'/','Retard2'],...
		'Delay Time','0.2',...
		'Initial Input','teta_zero',...
		'position',[265,209,325,241])

add_block('built-in/Transport Delay',[sys,'/','Retard1'])
set_param([sys,'/','Retard1'],...
		'orientation',2,...
		'Delay Time','0.5',...
		'Initial Input','teta_prim0',...
		'position',[390,419,450,451])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','C_roue',...
		'buffer','200',...
		'position',[565,145,645,175])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'hide name',0,...
		'Gain','1/It',...
		'position',[540,245,575,285])

add_block('built-in/Transport Delay',[sys,'/','Retard3'])
set_param([sys,'/','Retard3'],...
		'Delay Time','0.2',...
		'position',[595,249,655,281])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[715,169,735,311])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[333,825,1005,1075])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[600,115,620,135])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain2'])
set_param([sys,'/','Subsystem/Gain2'],...
		'hide name',0,...
		'position',[495,162,520,188])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant1'])
set_param([sys,'/','Subsystem/Constant1'],...
		'hide name',0,...
		'Value','4e-8',...
		'Mask Display','Couple aerod',...
		'position',[370,164,470,186])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant3'])
set_param([sys,'/','Subsystem/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple magneto\ninterne',...
		'position',[370,69,470,101])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain4'])
set_param([sys,'/','Subsystem/Gain4'],...
		'hide name',0,...
		'Gain','0',...
		'position',[495,72,520,98])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain3'])
set_param([sys,'/','Subsystem/Gain3'],...
		'hide name',0,...
		'Gain','0',...
		'position',[495,117,520,143])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant2'])
set_param([sys,'/','Subsystem/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'Mask Display','Couple magneto\nactuateurs',...
		'position',[370,116,470,144])

add_block('built-in/Sum',[sys,'/','Subsystem/Sum1'])
set_param([sys,'/','Subsystem/Sum1'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[550,60,570,200])
add_line([sys,'/','Subsystem'],[575,130;585,130;595,125])
add_line([sys,'/','Subsystem'],[475,175;490,175])
add_line([sys,'/','Subsystem'],[475,130;490,130])
add_line([sys,'/','Subsystem'],[475,85;490,85])
add_line([sys,'/','Subsystem'],[525,85;545,85])
add_line([sys,'/','Subsystem'],[525,175;545,175])
add_line([sys,'/','Subsystem'],[525,130;545,130])
set_param([sys,'/','Subsystem'],...
		'Mask Display','COUPLES\nPERTURBATEURS')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[510,299,635,351])

add_block('built-in/Fcn',[sys,'/','Fcn'])
set_param([sys,'/','Fcn'],...
		'Expr','-3*vitesse_rotation^2*(Ir-Il)*u(1)',...
		'position',[535,371,610,399])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','teta',...
		'buffer','500',...
		'position',[980,225,1060,255])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'hide name',0,...
		'position',[640,365,675,405])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','Cgg',...
		'buffer','500',...
		'position',[730,370,810,400])

add_block('built-in/Note',[sys,'/','Roue relle = Rponses  des capteurs  de position, de vitesse, et de la roue avec retards'])
set_param([sys,'/','Roue relle = Rponses  des capteurs  de position, de vitesse, et de la roue avec retards'],...
		'position',[450,510,455,515])

add_block('built-in/Note',[sys,'/',['Gradient de gravit pris en compte ( sortie du couple  Cgg',13,'']])
set_param([sys,'/',['Gradient de gravit pris en compte ( sortie du couple  Cgg',13,'']],...
		'position',[445,530,450,535])

add_block('built-in/Note',[sys,'/','Couples perturbateur  pris en compte ( couple aerodynamique )'])
set_param([sys,'/','Couples perturbateur  pris en compte ( couple aerodynamique )'],...
		'position',[460,550,465,555])

add_block('built-in/Note',[sys,'/',['Matrice d''inertie diagonale ( sans produits d''inertie )']])
set_param([sys,'/',['Matrice d''inertie diagonale ( sans produits d''inertie )']],...
		'position',[330,600,335,605])

add_block('built-in/Note',[sys,'/',['Initialisation par scaodat3 dans l''espace Matlab']])
set_param([sys,'/',['Initialisation par scaodat3 dans l''espace Matlab']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[845,585,850,590])

add_block('built-in/Note',[sys,'/',['Mode petits angles, jusqu'' 20']])
set_param([sys,'/',['Mode petits angles, jusqu'' 20']],...
		'position',[275,580,280,585])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','tetaprime',...
		'buffer','500',...
		'position',[985,110,1065,140])

add_block('built-in/Note',[sys,'/',['ROUE',13,'SIMPLE']])
set_param([sys,'/',['ROUE',13,'SIMPLE']],...
		'ForeGround',7,...
		'BackGround',7,...
		'Font Weight','bold',...
		'position',[395,325,400,330])


%     Subsystem  'Teta ( rd )'.

new_system([sys,'/','Teta ( rd )'])
set_param([sys,'/','Teta ( rd )'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Teta ( rd )/x'])
set_param([sys,'/','Teta ( rd )/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Teta ( rd )/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Teta ( rd )/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Teta ( rd )'],[90,65;125,65])
set_param([sys,'/','Teta ( rd )'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','Teta ( rd )'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','Teta ( rd )'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','Teta ( rd )'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','Teta ( rd )'],...
		'Mask Entries','5\/-10\/10\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Teta ( rd )'.

set_param([sys,'/','Teta ( rd )'],...
		'position',[985,160,1015,200])


%     Subsystem  'Couple roue ( Nm )'.

new_system([sys,'/','Couple roue ( Nm )'])
set_param([sys,'/','Couple roue ( Nm )'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Couple roue ( Nm )/x'])
set_param([sys,'/','Couple roue ( Nm )/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Couple roue ( Nm )/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Couple roue ( Nm )/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Couple roue ( Nm )'],[90,65;125,65])
set_param([sys,'/','Couple roue ( Nm )'],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/','Couple roue ( Nm )'],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/','Couple roue ( Nm )'],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/','Couple roue ( Nm )'],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/','Couple roue ( Nm )'],...
		'Mask Entries','5\/-10\/10\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Couple roue ( Nm )'.

set_param([sys,'/','Couple roue ( Nm )'],...
		'position',[675,85,705,125])

add_block('built-in/Note',[sys,'/','Simulink simclas4.m'])
set_param([sys,'/','Simulink simclas4.m'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Underline',1,...
		'Font Size',18,...
		'position',[1020,50,1025,55])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir la courbe\n\nteta (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,teta);grid;'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[980,490,1155,551])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\ntetaprime (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,tetaprime);grid;'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[980,410,1155,471])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir la courbe\n\nCouple roue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,C_roue);grid;'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[980,340,1155,401])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Initialisation par\n\nscaodat3.m',...
		'Mask Dialogue','eval(''scaodat3'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[980,265,1145,326])
add_line(sys,[810,240;850,240])
add_line(sys,[910,240;975,240])
add_line(sys,[740,240;755,240])
add_line(sys,[425,225;435,225])
add_line(sys,[415,300;435,300])
add_line(sys,[820,240;820,125;980,125])
add_line(sys,[190,200;210,200])
add_line(sys,[930,240;930,485;150,480;155,250;210,250])
add_line(sys,[931,240;930,180;980,180])
add_line(sys,[470,265;535,265])
add_line(sys,[205,130;270,130])
add_line(sys,[511,265;510,160;560,160])
add_line(sys,[510,160;510,105;670,105])
add_line(sys,[820,240;820,435;455,435])
add_line(sys,[385,435;275,435;275,300;335,300])
add_line(sys,[250,225;260,225])
add_line(sys,[330,225;340,225])
add_line(sys,[580,265;590,265])
add_line(sys,[660,265;670,265;670,195;710,195])
add_line(sys,[640,325;680,325;680,240;710,240])
add_line(sys,[615,385;635,385])
add_line(sys,[680,385;725,385])
add_line(sys,[695,385;695,285;710,285])
add_line(sys,[495,482;495,385;530,385])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
